@@ -1,5 +1,5 @@
 # copy from R2WinBUGS
-.decode.parameter.name <- function (a) 
+.decode.parameter.name <- function (a)
 {
     left.bracket <- regexpr("[[]", a)
     if (left.bracket == -1) {
@@ -22,21 +22,15 @@
 
 
 
-jags.sims <- function (parameters.to.save, n.chains, n.iter, n.burnin, n.thin, 
-  DIC = TRUE) 
+jags.sims <- function (parameters.to.save, n.chains, n.iter, n.burnin, n.thin,
+  DIC = TRUE)
 {
-  
+
   #require(R2WinBUGS)
   sims.files <- paste("CODAchain", 1:n.chains, ".txt", sep = "")
   index <- read.table("CODAindex.txt", header = FALSE)#, sep = "\t")
-  if (is.R()) {
-      parameter.names <- as.vector(index[, 1])
-      n.keep <- index[1, 3] - index[1, 2] + 1
-  }
-  else {
-      parameter.names <- row.names(index)
-      n.keep <- index[1, 2] - index[1, 1] + 1
-  }
+  parameter.names <- as.vector(index[, 1])
+  n.keep <- index[1, 3] - index[1, 2] + 1
   n.parameters <- length(parameter.names)
   n.sims <- n.keep * n.chains
   sims <- matrix(, n.sims, n.parameters)
@@ -51,8 +45,8 @@ jags.sims <- function (parameters.to.save, n.chains, n.iter, n.burnin, n.thin,
   n.roots <- length(parameters.to.save)
   left.bracket.short <- as.vector(regexpr("[[]", parameters.to.save))
   right.bracket.short <- as.vector(regexpr("[]]", parameters.to.save))
-  root.short <- ifelse(left.bracket.short == -1, parameters.to.save, 
-      substring(parameters.to.save, 1, left.bracket.short - 
+  root.short <- ifelse(left.bracket.short == -1, parameters.to.save,
+      substring(parameters.to.save, 1, left.bracket.short -
           1))
   dimension.short <- rep(0, n.roots)
   indexes.short <- vector(n.roots, mode = "list")
@@ -69,12 +63,12 @@ jags.sims <- function (parameters.to.save, n.chains, n.iter, n.burnin, n.thin,
           dimension.short[j] <- length(indexes.long[[long.short[[j]][1]]])
           n.indexes.short[[j]] <- numeric(dimension.short[j])
           for (k in 1:dimension.short[j]){
-            n.indexes.short[[j]][k] <- length(unique(unlist(lapply(indexes.long[long.short[[j]]], 
+            n.indexes.short[[j]][k] <- length(unique(unlist(lapply(indexes.long[long.short[[j]]],
               .subset, k))))
           }
           length.short[j] <- prod(n.indexes.short[[j]])
-          if (length(long.short[[j]]) != length.short[j]){ 
-              stop(paste("error in parameter", root.short[[j]], 
+          if (length(long.short[[j]]) != length.short[j]){
+              stop(paste("error in parameter", root.short[[j]],
                 "in parameters.to.save"))
           }
           indexes.short[[j]] <- as.list(numeric(length.short[j]))
@@ -85,13 +79,8 @@ jags.sims <- function (parameters.to.save, n.chains, n.iter, n.burnin, n.thin,
   }
   rank.long <- unlist(long.short)
   for (i in 1:n.chains) {
-      if (is.R()) {
-          sims.i <- scan(sims.files[i], quiet = TRUE)[2 * (1:(n.keep * 
-              n.parameters))]
-      }
-      else {
-          sims.i <- scan(sims.files[i])[2 * (1:(n.keep * n.parameters))]
-      }
+      sims.i <- scan(sims.files[i], quiet = TRUE)[2 * (1:(n.keep *
+                                                          n.parameters))]
       sims[(n.keep * (i - 1) + 1):(n.keep * i), ] <- sims.i
       sims.array[, i, ] <- sims.i
   }
@@ -106,19 +95,19 @@ jags.sims <- function (parameters.to.save, n.chains, n.iter, n.burnin, n.thin,
       names(last.values[[i]]) <- root.short[1:n.roots.0]
       for (j in 1:n.roots.0) {
           if (dimension.short[j] <= 1) {
-              last.values[[i]][[j]] <- sims.array[n.keep, i, 
+              last.values[[i]][[j]] <- sims.array[n.keep, i,
                 long.short[[j]]]
               names(last.values[[i]][[j]]) <- NULL
           }
           else{
-            last.values[[i]][[j]] <- aperm(array(sims.array[n.keep, 
-                i, long.short[[j]]], rev(n.indexes.short[[j]])), 
+            last.values[[i]][[j]] <- aperm(array(sims.array[n.keep,
+                i, long.short[[j]]], rev(n.indexes.short[[j]])),
                 dimension.short[j]:1)
           }
       }
   }
   sims <- sims[sample(n.sims), , drop = FALSE]
-  sims.list <- summary.mean <- summary.sd <- summary.median <- vector(n.roots, 
+  sims.list <- summary.mean <- summary.sd <- summary.median <- vector(n.roots,
       mode = "list")
   names(sims.list) <- names(summary.mean) <- names(summary.sd) <- names(summary.median) <- root.short
   for (j in 1:n.roots) {
@@ -128,32 +117,32 @@ jags.sims <- function (parameters.to.save, n.chains, n.iter, n.burnin, n.thin,
           summary.sd[[j]] <- summary[long.short[[j]], "sd"]
           summary.median[[j]] <- summary[long.short[[j]], "50%"]
       }
-      else { 
+      else {
         sims.list[[j]] <- array(sims[, long.short[[j]]], c(n.sims, rev(n.indexes.short[[j]])))#, c(1, (dimension.short[j] + 1):2))
         #sims.list[[j]] <- sims[, long.short[[j]]]
         summary.mean[[j]] <- array(summary[long.short[[j]],"mean"],n.indexes.short[[j]])
         summary.sd[[j]] <- array(summary[long.short[[j]],"sd"],n.indexes.short[[j]])
         summary.median[[j]] <- array(summary[long.short[[j]],"50%"],n.indexes.short[[j]])
 #          temp2 <- dimension.short[j]:1
-#          sims.list[[j]] <- aperm(array(sims[, long.short[[j]]], 
-#              c(n.sims, rev(n.indexes.short[[j]]))), c(1, (dimension.short[j] + 
+#          sims.list[[j]] <- aperm(array(sims[, long.short[[j]]],
+#              c(n.sims, rev(n.indexes.short[[j]]))), c(1, (dimension.short[j] +
 #              1):2))
-#          summary.mean[[j]] <- aperm(array(summary[long.short[[j]], 
+#          summary.mean[[j]] <- aperm(array(summary[long.short[[j]],
 #              "mean"], rev(n.indexes.short[[j]])), temp2)
-#          summary.sd[[j]] <- aperm(array(summary[long.short[[j]], 
+#          summary.sd[[j]] <- aperm(array(summary[long.short[[j]],
 #              "sd"], rev(n.indexes.short[[j]])), temp2)
-#          summary.median[[j]] <- aperm(array(summary[long.short[[j]], 
+#          summary.median[[j]] <- aperm(array(summary[long.short[[j]],
 #              "50%"], rev(n.indexes.short[[j]])), temp2)
       }
   }
-  
+
   summary <- summary[rank.long,, drop = FALSE]
-  all <- list(n.chains = n.chains, n.iter = n.iter, n.burnin = n.burnin, 
-      n.thin = n.thin, n.keep = n.keep, n.sims = n.sims, sims.array = sims.array[, 
-          , rank.long, drop = FALSE], sims.list = sims.list, 
-      sims.matrix = sims[, rank.long, drop = FALSE], summary = summary, mean = summary.mean, 
-      sd = summary.sd, median = summary.median, root.short = root.short, 
-      long.short = long.short, dimension.short = dimension.short, 
+  all <- list(n.chains = n.chains, n.iter = n.iter, n.burnin = n.burnin,
+      n.thin = n.thin, n.keep = n.keep, n.sims = n.sims, sims.array = sims.array[,
+          , rank.long, drop = FALSE], sims.list = sims.list,
+      sims.matrix = sims[, rank.long, drop = FALSE], summary = summary, mean = summary.mean,
+      sd = summary.sd, median = summary.median, root.short = root.short,
+      long.short = long.short, dimension.short = dimension.short,
       indexes.short = indexes.short, last.values = last.values)
   if (DIC) {
     deviance <- all$sims.array[, , "deviance", drop = FALSE]
@@ -165,7 +154,7 @@ jags.sims <- function (parameters.to.save, n.chains, n.iter, n.burnin, n.thin,
       pD[i] <- var(deviance[, i])/2
       DIC[i] <- mean(deviance[, i]) + pD[i]
     }
-    all <- c(all, list(isDIC = TRUE, DICbyR = TRUE, pD = mean(pD), 
+    all <- c(all, list(isDIC = TRUE, DICbyR = TRUE, pD = mean(pD),
                 DIC = mean(DIC)))
   }
   else {
@@ -173,5 +162,3 @@ jags.sims <- function (parameters.to.save, n.chains, n.iter, n.burnin, n.thin,
   }
   all
 }
-
-if(!is.R()) .subset <- function(x, index) x[index]
